@@ -11,7 +11,7 @@ has store => qw/ is ro required 1 weak_ref 1 /;
 has model => qw/ is ro lazy_build 1 /;
 sub _build_model {
     my $self = shift;
-    my $model = $self->store->model( '__Store_Stash__' );
+    my $model = $self->store->model( '__NoSQL_Stash__' );
     $model->searchable( 0 );
     return $model;
 }
